@@ -3,11 +3,7 @@
    and 128 bit addition
 */
 
-#if defined(__SIZEOF_INT128__)
-typedef unsigned __int128 uint128_t;
-#else
-typedef unsigned uint128_t __attribute__((mode(TI)));
-#endif
+#include "private/common.h"
 
 #define MUL(out, x, y) out = ((uint128_t) x * y)
 #define ADD(out, in) out += in
@@ -23,8 +19,6 @@ typedef unsigned uint128_t __attribute__((mode(TI)));
 # define POLY1305_NOINLINE
 #endif
 
-#include "private/common.h"
-
 #define poly1305_block_size 16
 
 /* 17 + sizeof(unsigned long long) + 8*sizeof(unsigned long long) */
