@@ -6,6 +6,7 @@
 #ifdef __native_client__
 # include <irt.h>
 
+# include "core.h"
 # include "utils.h"
 # include "randombytes.h"
 # include "randombytes_nativeclient.h"
@@ -20,12 +21,12 @@ randombytes_nativeclient_buf(void * const buf, const size_t size)
 
     if (nacl_interface_query(NACL_IRT_RANDOM_v0_1, &rand_intf,
                              sizeof rand_intf) != sizeof rand_intf) {
-        abort();
+        sodium_misuse();
     }
     while (toread > (size_t) 0U) {
         if (rand_intf.get_random_bytes(buf_, size, &readnb) != 0 ||
             readnb > size) {
-            abort();
+            sodium_misuse();
         }
         toread -= readnb;
         buf_ += readnb;
