@@ -14,12 +14,12 @@
 
 from __future__ import absolute_import, division, print_function
 
+import os
+
 import six
 
-import nacl.bindings
 
-
-class EncryptedMessage(six.binary_type):
+class EncryptedMessage(bytes):
     """
     A bytes subclass that holds a messaged that has been encrypted by a
     :class:`SecretBox`.
@@ -51,7 +51,7 @@ class StringFixer(object):
 
     def __str__(self):
         if six.PY3:
-            return self.__unicode__()
+            return str(self.__bytes__())
         else:
             return self.__bytes__()
 
@@ -64,4 +64,4 @@ def bytes_as_string(bytes_in):
 
 
 def random(size=32):
-    return nacl.bindings.randombytes(size)
+    return os.urandom(size)
