@@ -1,4 +1,4 @@
-# Copyright 2013 Donald Stufft and individual contributors
+# Copyright 2013-2018 Donald Stufft and individual contributors
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,7 +18,10 @@ import binascii
 
 import pytest
 
+from utils import flip_byte
+
 from nacl.encoding import HexEncoder
+from nacl.exceptions import CryptoError
 from nacl.secret import SecretBox
 
 
@@ -149,3 +152,25 @@ def test_wrong_types():
                      SecretBox, 12)
     check_type_error("SecretBox must be created from 32 bytes",
                      SecretBox, box)
+
+
+def test_secret_box_bad_decryption():
+    box = SecretBox(b"\x11" * 32)
+    ciphertext = box.encrypt(b"hello")
+
+    with pytest.raises(CryptoError):
+        # changes the nonce
+        box.decrypt(flip_byte(ciphertext, 0))
+    with pytest.raises(CryptoError):
+        # changes ciphertext
+        box.decrypt(flip_byte(ciphertext, 24))
+    with pytest.raises(CryptoError):
+        # changes MAC tag
+        box.decrypt(flip_byte(ciphertext, len(ciphertext) - 1))
+
+    with pytest.raises(CryptoError):
+        # completely changes ciphertext and tag
+        box.decrypt(ciphertext + b"\x00")
+    with pytest.raises(CryptoError):
+        # completely changes everything
+        box.decrypt(b"\x00" + ciphertext)
